@@ -78,21 +78,24 @@ class ADOGitClient(ADOBaseClient):
     def __init__(self, http_client: ADOHTTPClient, log: logging.Logger) -> None:
         super().__init__(http_client, log.getChild("git"))
 
-    def all_repositories(self) -> ADOResponse:
+    def all_repositories(self, project_id: str) -> ADOResponse:
         """Get a list of repositories in the project.
 
+        :param str project_id: The ID of the project
+
         :returns: The ADO response with the data in it
         """
         self.log.debug("Getting repositories")
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories/?api-version=1.0"
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/?api-version=1.0"
         response = self.http_client.get(request_url)
         response_data = self.http_client.decode_response(response)
         return self.http_client.extract_value(response_data)
 
-    def get_status(self, *, sha: str, repository_id: str) -> ADOResponse:
+    def get_status(self, *, sha: str, project_id: str, repository_id: str) -> ADOResponse:
         """Set a status on a PR.
 
         :param str sha: The SHA of the commit to add the status to.
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
@@ -106,9 +109,9 @@ class ADOGitClient(ADOBaseClient):
             raise ADOException("The SHA for a commit must be the full 40 character version")
 
         request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}/commits/{sha}/"
+            self.http_client.api_endpoint(project_id=project_id)
+            + f"/git/repositories/{repository_id}/commits/{sha}/statuses?api-version=2.1"
         )
-        request_url += "statuses?api-version=2.1"
 
         response = self.http_client.get(request_url)
         response_data = self.http_client.decode_response(response)
@@ -121,6 +124,7 @@ class ADOGitClient(ADOBaseClient):
         state: ADOGitStatusState,
         identifier: str,
         description: str,
+        project_id: str,
         repository_id: str,
         context: str,
         target_url: Optional[str] = None,
@@ -131,6 +135,7 @@ class ADOGitClient(ADOBaseClient):
         :param ADOGitStatusState state: The state to set the status to.
         :param str identifier: A unique identifier for the status (so it can be changed later)
         :param str description: The text to show in the status
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
         :param str context: The context to use for build status notifications
         :param Optional[str] target_url: An optional URL to set which is opened when the description is clicked.
@@ -149,7 +154,8 @@ class ADOGitClient(ADOBaseClient):
             raise ADOException("The NOT_SET state cannot be used for statuses on commits")
 
         request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}/commits/{sha}/"
+            self.http_client.api_endpoint(project_id=project_id)
+            + f"/git/repositories/{repository_id}/commits/{sha}/"
         )
         request_url += "statuses?api-version=2.1"
 
@@ -166,12 +172,13 @@ class ADOGitClient(ADOBaseClient):
         return self.http_client.decode_response(response)
 
     def diff_between_commits(
-        self, *, base_commit: str, target_commit: str, repository_id: str,
+        self, *, base_commit: str, target_commit: str, project_id: str, repository_id: str,
     ) -> ADOResponse:
         """Get the diff between two commits.
 
         :param str base_commit: The full hash of the base commit to perform the diff against.
         :param str target_commit: The full hash of the commit to perform the diff of.
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
@@ -180,7 +187,8 @@ class ADOGitClient(ADOBaseClient):
         self.log.debug(f"Fetching commit diff: {base_commit}..{target_commit}")
 
         base_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}/diffs/commits?"
+            self.http_client.api_endpoint(project_id=project_id)
+            + f"/git/repositories/{repository_id}/diffs/commits?"
         )
 
         changes = []
@@ -211,11 +219,14 @@ class ADOGitClient(ADOBaseClient):
 
             skip += 100
 
-    def download_zip(self, *, branch: str, output_path: str, repository_id: str,) -> None:
+    def download_zip(
+        self, *, branch: str, output_path: str, project_id: str, repository_id: str,
+    ) -> None:
         """Download the zip of the branch specified.
 
         :param str branch: The name of the branch to download.
         :param str output_path: The path to write the output to.
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
 
         :raises ADOException: If the output path already exists
@@ -223,7 +234,7 @@ class ADOGitClient(ADOBaseClient):
         """
 
         self.log.debug(f"Downloading branch: {branch}")
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}/Items?"
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}/Items?"
 
         parameters = {
             "path": "/",
@@ -243,9 +254,11 @@ class ADOGitClient(ADOBaseClient):
         with self.http_client.get(request_url, stream=True) as response:
             download_from_response_stream(response=response, output_path=output_path, log=self.log)
 
+    # pylint: disable=too-many-locals
     def get_refs(
         self,
         *,
+        project_id: str,
         repository_id: str,
         filter_startswith: Optional[str] = None,
         filter_contains: Optional[str] = None,
@@ -261,6 +274,7 @@ class ADOGitClient(ADOBaseClient):
 
         All non-specified options use the ADO default.
 
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
         :param Optional[str] filter_startswith: A filter to apply to the refs
                                                 (starts with)
@@ -297,7 +311,7 @@ class ADOGitClient(ADOBaseClient):
 
         self.log.debug(f"Getting refs")
 
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}/refs?"
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}/refs?"
 
         parameters: Dict[str, Any] = {}
 
@@ -341,14 +355,22 @@ class ADOGitClient(ADOBaseClient):
 
         # pylint: enable=too-complex
 
+    # pylint: enable=too-many-locals
+
     def get_commit(
-        self, *, commit_id: str, repository_id: str, change_count: Optional[int] = None
+        self,
+        *,
+        commit_id: str,
+        project_id: str,
+        repository_id: str,
+        change_count: Optional[int] = None,
     ) -> ADOResponse:
         """Set a status on a PR.
 
         All non-specified options use the ADO default.
 
         :param str commit_id: The id of the commit
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
         :param Optional[int] change_count: The number of changes to include in
                                            the result
@@ -358,7 +380,7 @@ class ADOGitClient(ADOBaseClient):
 
         self.log.debug(f"Getting commit: {commit_id}")
 
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}"
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}"
         request_url += f"/commits/{commit_id}?api-version=5.0"
 
         if change_count:
@@ -367,10 +389,13 @@ class ADOGitClient(ADOBaseClient):
         response = self.http_client.get(request_url)
         return self.http_client.decode_response(response)
 
-    def update_refs(self, *, updates: List[ADOReferenceUpdate], repository_id: str,) -> ADOResponse:
+    def update_refs(
+        self, *, updates: List[ADOReferenceUpdate], project_id: str, repository_id: str,
+    ) -> ADOResponse:
         """Update a list of references.
 
         :param List[ADOReferenceUpdate] updates: The list of updates to make
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
@@ -378,7 +403,7 @@ class ADOGitClient(ADOBaseClient):
 
         self.log.debug("Updating references")
 
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}"
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}"
         request_url += "/refs?api-version=5.0"
 
         data = [update.json_data() for update in updates]
@@ -387,17 +412,22 @@ class ADOGitClient(ADOBaseClient):
         response_data = self.http_client.decode_response(response)
         return self.http_client.extract_value(response_data)
 
-    def delete_branch(self, branch_name: str, object_id: str, repository_id: str) -> ADOResponse:
+    def delete_branch(
+        self, branch_name: str, object_id: str, project_id: str, repository_id: str
+    ) -> ADOResponse:
         """Delete a branch
 
         :param branch_name: The full name of the branch. e.g. refs/heads/my_branch
         :param object_id: The ID of the object the branch currently points to
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
 
         :returns: The ADO response
         """
         return self.update_refs(
-            updates=[ADOReferenceUpdate(branch_name, object_id, None)], repository_id=repository_id
+            updates=[ADOReferenceUpdate(branch_name, object_id, None)],
+            project_id=project_id,
+            repository_id=repository_id,
         )
 
     class VersionControlRecursionType(enum.Enum):
@@ -422,10 +452,12 @@ class ADOGitClient(ADOBaseClient):
         commit = "commit"
         tag = "tag"
 
+    # pylint: disable=too-many-locals
     def get_item(
         self,
         *,
         path: str,
+        project_id: str,
         repository_id: str,
         scope_path: Optional[str] = None,
         recursion_level: Optional[VersionControlRecursionType] = None,
@@ -442,6 +474,7 @@ class ADOGitClient(ADOBaseClient):
         All non-specified options use the ADO default.
 
         :param str path: The item path,
+        :param str project_id: The ID of the project
         :param str repository_id: The ID for the repository
         :param Optional[str] scope_path: The path scope
         :param Optional[VersionControlRecursionType] recursion_level: The recursion level
@@ -458,7 +491,7 @@ class ADOGitClient(ADOBaseClient):
 
         self.log.debug(f"Getting item")
 
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}/items?"
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}/items?"
 
         parameters: Dict[str, Any] = {"path": path, "api-version": "5.1"}
 
@@ -494,6 +527,8 @@ class ADOGitClient(ADOBaseClient):
         response = self.http_client.get(request_url)
         return self.http_client.decode_response(response)
 
+    # pylint: enable=too-many-locals
+
     class BlobFormat(enum.Enum):
         """The type of format to get a blob in."""
 
@@ -506,6 +541,7 @@ class ADOGitClient(ADOBaseClient):
         self,
         *,
         blob_id: str,
+        project_id: str,
         repository_id: str,
         blob_format: Optional[BlobFormat] = None,
         download: Optional[bool] = None,
@@ -517,6 +553,7 @@ class ADOGitClient(ADOBaseClient):
         All non-specified options use the ADO default.
 
         :param str blob_id: The SHA1 of the blob
+        :param str project_id: The ID for the project
         :param str repository_id: The ID for the repository
         :param Optional[BlobFormat] blob_format: The format to get the blob in
         :param Optional[bool] download: Set to True to download rather than get a response
@@ -528,7 +565,9 @@ class ADOGitClient(ADOBaseClient):
 
         self.log.debug(f"Getting blob")
 
-        request_url = self.http_client.api_endpoint(is_default_collection=False)
+        request_url = self.http_client.api_endpoint(
+            is_default_collection=False, project_id=project_id
+        )
         request_url += f"/git/repositories/{repository_id}/blobs/{blob_id}?"
 
         parameters: Dict[str, Any] = {
@@ -558,7 +597,7 @@ class ADOGitClient(ADOBaseClient):
         return self.http_client.decode_response(response)
 
     def get_blobs(
-        self, *, blob_ids: List[str], output_path: str, repository_id: str,
+        self, *, blob_ids: List[str], output_path: str, project_id: str, repository_id: str,
     ) -> ADOResponse:
         """Get a git item.
 
@@ -566,6 +605,7 @@ class ADOGitClient(ADOBaseClient):
 
         :param List[str] blob_ids: The SHA1s of the blobs
         :param str output_path: The location to write out the zip to
+        :param str project_id: The ID for the project
         :param str repository_id: The ID for the repository
 
         :raises FileExistsError: If the output path already exists
@@ -573,7 +613,9 @@ class ADOGitClient(ADOBaseClient):
 
         self.log.debug(f"Getting blobs")
 
-        request_url = self.http_client.api_endpoint(is_default_collection=False)
+        request_url = self.http_client.api_endpoint(
+            is_default_collection=False, project_id=project_id
+        )
         request_url += f"/git/repositories/{repository_id}/blobs?api-version=5.1"
 
         if os.path.exists(output_path):
